##  Adding a Dashboard to Favorites
You can mark user-defined dashboards as favorites for quick access to frequently used dashboards. To do this, in the dashboards list, click on the star icon on the dashboard. You can also mark a dashboard as a favorite from the dashboard details page.
![Markin](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2752d36c7a4410149400bb71dff25730_LowRes.png)
Marking a Dashboard as a Favorite
Dashboards that you mark as favorites are indicated by a blue star. They appear in the Favorites section in the Personal collection.
**Note**
There is no limit to the number of favorites you can have, but marking too many dashboards as favorites may defeat the purpose.
